@@ -52,8 +52,8 @@ analysis = Table(
     Column("work_dir", String(255)),
     Column("params_path", String(255)),
     Column("command_path", String(255)),
-    Column("request_param", Text),
-    Column("output_format", Text),
+    Column("request_param", Text().with_variant(LONGTEXT(), "mysql")),
+    Column("output_format", Text().with_variant(LONGTEXT(), "mysql")),
     Column("output_dir", String(255)),
     Column("pipeline_script", String(255)),
     Column("parse_analysis_module", String(255)),
@@ -62,11 +62,17 @@ analysis = Table(
     Column("executor_log_file", String(255)),
     Column("process_id", String(255)),
     Column("script_config_file", String(255)),
-    Column("analysis_status", String(255)),
+    # Column("analysis_status", String(255)),
     Column("job_id", String(255)),
     Column("ports", String(255)),
     Column("url", String(255)),
-    Column("run_type", String(255)),
+    # Column("run_type", String(255)),
+    # Column("job_id", String(255)),
+    # Column("server_id", String(255)),
+    Column("job_status", String(255)),
+    Column("server_status", String(255)),
+
+
     Column("command_log_path", String(255)),
     Column("is_report", Boolean, default=False),
 
@@ -93,7 +99,7 @@ analysis_result = Table(
     Column("component_id", String(255)),
     # Column("analysis_method", String(255)),
     Column("software", String(255)),
-    Column("content", String(255)),
+    Column("content",Text().with_variant(LONGTEXT(), "mysql")),
     Column("analysis_version", String(255)),
     Column("content_type", String(255)),
     Column("analysis_id", String(255)),
@@ -161,7 +167,7 @@ t_pipeline_components = Table(
     Column("sub_container_id", String(255)),
     Column("tags", String(255)), 
     Column("category", String(255)), 
-    Column("namespace", String(255)),
+    # Column("namespace", String(255)),
     Column("content", Text),
     Column("order_index", Integer),
     Column("position", Text),
@@ -180,7 +186,7 @@ t_pipeline_components_relation = Table(
     Column("component_id", String(255)),
     Column("parent_component_id", String(255)),
     Column("order_index", Integer),
-    Column("namespace", String(255)),
+    # Column("namespace", String(255)),
     Column("created_at", DateTime, default=datetime.now),
     Column("updated_at", DateTime, onupdate=datetime.now)
 
@@ -215,6 +221,8 @@ t_namespace = Table(
     Column("id", Integer, primary_key=True),
     Column("namespace_id", String(255)),
     Column("name", String(255)),
+    Column("volumes", Text().with_variant(LONGTEXT(), "mysql")),
+    Column("is_use",  Boolean, default=False),
 )
 
 # t_relation_pipeline_software = Table(
@@ -285,10 +293,14 @@ t_container = Table(
     meta,
     Column("id", Integer, primary_key=True),
     Column("container_id", String(255)),
+    Column("container_key", String(255)),
     Column("name", String(255)),
     Column("image", String(255)),
+    Column("img",  Text().with_variant(LONGTEXT(), "mysql")),
+    Column("image_id", String(255)),
+    Column("image_status", String(255)),
     Column("description", String(255)),
-    Column("namespace", String(255)),
+    # Column("namespace", String(255)),
     Column("envionment", String(255)),
     Column("command", String(255)),
     Column("port", String(255)),
