@@ -31,6 +31,7 @@ import os
 from brave.api.service.result_parse import script_analysis
 from brave.api.service.result_parse import nextflow_analysis
 from brave.api.service.result_parse.nextflow_analysis    import NextflowAnalysis
+from brave.api.service.result_parse.result_parse import ResultParse
 from brave.api.utils.get_db_utils import get_ids
 from brave.api.config.config import get_settings
 from brave.api.routes.pipeline import get_pipeline_file
@@ -39,7 +40,6 @@ import textwrap
 from brave.api.routes.sample_result import parse_result_one
 import  brave.api.service.pipeline as pipeline_service
 import brave.api.service.bio_database_service as bio_database_service
-import inspect
 from typing import Optional
 import pandas as pd
 import subprocess
@@ -166,45 +166,24 @@ async def browse_output_dir(analysis_id):
 @inject
 async def parse_analysis_result(
     analysis_id,save:Optional[bool]=False,
-    analysis_result_parse_service:AnalysisResultParse = Depends(Provide[AppContainer.analysis_result_parse_service])):
+    event_bus:EventBus = Depends(Provide[AppContainer.event_bus]) 
+   ):
+
+
+    resultParse = ResultParse(analysis_id,event_bus)
+    
     with get_engine().begin() as conn:
         if save:
-            result = await analysis_result_parse_service.save_analysis_result_preview(conn,analysis_id)
+            result_list,result_dict,params = await resultParse.parse(True)
+            # result = await analysis_result_parse_service.save_analysis_result_preview(conn,analysis_id)
         else:
-            result = await analysis_result_parse_service.parse_analysis_result_preview(conn,analysis_id)
-        return result
-    #     params :Any = analysis_service.get_parse_analysis_result_params(conn,analysis_id)
-    #     result_list,result_dict = analysis_service.execute_parse(**params)
-
-
-    #     analysis :Any = params["analysis"]
-    #     file_format_list = params["file_format_list"]
-    #     file_dict = analysis_service.get_file_dict(file_format_list,analysis['output_dir'])
-            
-    #     if save:
-    #         for item in result_list:
-    #             result = analysis_result_service.find_analysis_result_exist(conn,item['component_id'],item['file_name'],item['project'])
-    #             if not result:
-    #                 find_sample = sample_service.find_by_sample_name_and_project(conn,item['sample_name'],item['project'])
-    #                 if find_sample:
-    #                     item['sample_id'] = find_sample['sample_id']
-    #                 analysis_result_service.add_analysis_result(conn,item)
-    #             else:
-    #                 if item['analysis_result_hash']!= result['analysis_result_hash']:
-    #                     analysis_result_service.update_analysis_result(conn,result.id,item)
-                    
-    #         # sample_name_list = [item['file_name'] for item in result_list]
-    #         # sample_list = sample_service.find_by_sample_name_list(conn,sample_name_list)
-    #         # sample_dict = {item['sample_name']:item for item in sample_list}
-    #         # for item in result_list:
-    #         #     if item['file_name'] in sample_dict:
-    #         #         item['sample_id'] = sample_dict[item['file_name']]['sample_id']
-    #         #     else:
-    #         #         raise HTTPException(status_code=500, detail=f"样本{item['file_name']}不存在!")
-    #         # analysis_result_service.save_or_update_analysis_result_list( conn,result_list)
-    #         # parse_result_oneV2(res,item['name'],result['project'],"V1.0",analysis_id)
-    # return {"result_dict":result_dict,"file_format_list":file_format_list,"file_dict":file_dict}
+            # result = await analysis_result_parse_service.parse_analysis_result_preview(conn,analysis_id)
+            result_list,result_dict,params = await resultParse.parse(False)
 
+        file_format_list = params["file_format_list"]
+        file_dict = analysis_service.get_file_dict(file_format_list,params['analysis']['output_dir'])
+        # file_dict = find_file_dict(file_format_list,params['analysis']['output_dir'])   
+        return {"result_dict":result_dict,"file_format_list":file_format_list,"file_dict":file_dict}
 
 
 @analysis_api.post(
@@ -503,21 +482,23 @@ async def run_analysis_v2(
 
         # find_container = container_service.find_container_by_id(conn,analysis_["container_id"])
         analysis_ = dict(analysis_)
-        analysis_["run_type"] = run_type
+        analysis_["run_id"] = f"{run_type}-{analysis_id}"
+        
         if run_type == "job":
             analysis_["container_id"] =component["container_id"]
         else:
-            if component_type=="script":
-                analysis_["container_id"] =component["container_id"]
-            else: 
-                if not component["sub_container_id"]:
-                    raise HTTPException(status_code=500, detail=f"please config sub_container_id id") 
-                analysis_["container_id"] = component["sub_container_id"]
+            # if component_type=="script":
+            analysis_["container_id"] =component["container_id"]
+            # else: 
+            #     if not component["sub_container_id"]:
+            #         raise HTTPException(status_code=500, detail=f"please config sub_container_id id") 
+            #     analysis_["container_id"] = component["sub_container_id"]
 
         # analysis_["image"] = find_container["image"]
         analysis_ = AnalysisExecuterModal(**analysis_)
         # analysis_.image = find_container["image"]
-        stmt = analysis.update().values({"analysis_status":"running","run_type":run_type}).where(analysis.c.analysis_id==analysis_id)
+        await analysis_service.finished_analysis(analysis_id,run_type,"running")
+        # stmt = analysis.update().values({"analysis_status":"running","run_type":run_type}).where(analysis.c.analysis_id==analysis_id)
         conn.execute(stmt)
     await evenet_bus.dispatch(RoutersName.ANALYSIS_EXECUTER_ROUTER,AnalysisExecutorEvent.ON_ANALYSIS_SUBMITTED,analysis_)
     
@@ -536,6 +517,7 @@ async def run_analysis_v2(
 @inject
 async def stop_analysis(
     analysis_id,
+    run_type,
     evenet_bus:EventBus = Depends(Provide[AppContainer.event_bus]) 
     ):
 
@@ -547,55 +529,17 @@ async def stop_analysis(
         if analysis_ is None:
             raise HTTPException(status_code=404, detail="Analysis not found")
         
-
-        analysis_ = AnalysisExecuterModal(**analysis_)
+        run_id = f"{run_type}-{analysis_id}"
+        analysis_ = AnalysisExecuterModal(**analysis_,run_id=run_id)
+        
         # stmt = analysis.update().values({"analysis_status":"running"}).where(analysis.c.analysis_id==analysis_id)
         # conn.execute(stmt)
+
         await evenet_bus.dispatch(RoutersName.ANALYSIS_EXECUTER_ROUTER,AnalysisExecutorEvent.ON_ANALYSIS_STOPED,analysis_)
         
     
         return {"msg":"success"}
 
-    #     analysis_dict = dict(analysis_)
-    #     analysis_dict['job_id'] = job_id
-    #     await process_monitor.add_process(analysis_dict)
-    #     if auto_parse:
-    #         await analysis_result_parse_service.add_analysis_id(analysis_id)
-    #     if process_id is not None:
-    #         try:
-    #             proc = psutil.Process(int(process_id))
-    #             if proc.is_running():
-    #                 raise Exception(f"Analysis is already running with process_id={process_id}")
-    #         except (psutil.NoSuchProcess, ValueError):
-    #             pass  # 进程不存在或 process_id 非法，继续执行
-        
-    #     pid = start_background(analysis_.output_dir, ["bash","run.sh"])
-    #     stmt = analysis.update().values({"process_id":pid,"analysis_status":"running"}).where(analysis.c.analysis_id==analysis_id)
-    #     conn.execute(stmt)
-    #     analysis_dict = dict(analysis_)
-
-    #     analysis_dict['process_id'] = pid
-    #     # await queue_process.put(analysis_dict)
-    #     await process_monitor.add_process(analysis_dict)
-    #     if auto_parse:
-    #         await analysis_result_parse_service.add_analysis_id(analysis_id)
-    # return {"pid":pid}
-
-
-# @analysis_api.get("/monitor-analysis/{analysis_id}")
-# async def pipeline_monitor(analysis_id):
-#     with get_engine().begin() as conn:
-#         stmt = select(analysis).where(analysis.c.id == analysis_id)
-#         result = conn.execute(stmt)
-#         result = result.mappings().fetchone()
-#     if not result:
-#         return {}
-
-#     output_dir = result['output_dir']
-#     trace_file = f"{output_dir}/trace.txt"
-#     if os.path.exists(trace_file):
-#         df = pd.read_csv(trace_file,sep="\t")
-#     return  df.to_dict(orient="records")   
 
 @analysis_api.get("/find-analysis-by-id/{analysis_id}") 
 async def find_analysis_by_id(analysis_id):
@@ -659,10 +603,10 @@ async def visualization_results(analysis_id):
     # file_result = {}
     file_result['description'] = find_component["description"]
     file_result['analysis_name'] = find_analysis["analysis_name"]
-    file_result['analysis_status'] = find_analysis["analysis_status"]
+    file_result['job_status'] = find_analysis["job_status"]
+    file_result['server_status'] = find_analysis["server_status"]
     file_result['is_report'] = find_analysis["is_report"]
     file_result['analysis_id'] = find_analysis["analysis_id"]
-    file_result['run_type'] = find_analysis["run_type"]
 
     file_result['component_name'] = find_component["component_name"]
     file_result['component_id'] = find_component["component_id"]
@@ -743,6 +687,7 @@ async def edit_params(analysis_id):
         "is_report":find_analysis["is_report"],
         "analysis_id":find_analysis["analysis_id"],
         "component_name":find_component["component_name"],
+        "component_type":find_component["component_type"],
         "component_id":find_component["component_id"],
         "request_param":json.loads(find_analysis["request_param"]),
         "content":json.loads(find_component["content"]),
