@@ -10,10 +10,15 @@ class SaveContainer(BaseModel):
     image: Optional[str]
     container_id: Optional[str]=None
     description: Optional[str]=None
-    namespace:Optional[str]
     envionment:Optional[str]=None
     command: Optional[str]=None
     port: Optional[str]=None
     labels: Optional[str]=None
     change_uid:Optional[bool]=True
+    container_key:Optional[str]=None
+    img: Optional[str]=None
+    
+
+class ListContainerQuery(BaseModel):
+    container_key: Optional[list]=None
 
