@@ -1,4 +1,3 @@
-from tkinter import N
 from typing import Optional
 from pydantic import BaseModel
 
@@ -81,4 +80,7 @@ class SaveOrder(BaseModel):
 class SavePipelineComponentsEdges(BaseModel):
     component_id: str
     edges: str
-    position:str
\ No newline at end of file
+    position:str
+
+class InstallComponent(BaseModel):
+    path: str
