@@ -1,4 +1,4 @@
-from operator import and_
+from operator import and_, or_
 from brave.api.config.db import get_engine
 from brave.api.models.core import analysis as t_analysis, t_pipeline_components,t_project
 from sqlalchemy import select,update
@@ -64,7 +64,6 @@ def get_parse_analysis_result_params(conn,analysis_id):
         # raise HTTPException(status_code=500, detail=f"组件{component_id}的输出文件没有配置fileFormat!请检查!")
 
 
-    # py_module = pipeline_service.find_module(component_.namespace,"py_parse_analysis_result",component_id,parse_analysis_result_module,'py')['module']
     module_info = pipeline_service.find_component_module(component_, ScriptName.output_parse)
     if not module_info:
         raise HTTPException(status_code=500, detail=f"组件{component_id}的输出解析模块没有找到!")
@@ -82,6 +81,18 @@ def get_parse_analysis_result_params(conn,analysis_id):
 
 
 def execute_parse(analysis,parse,file_format_list):
+    analysis_params_path = analysis.get('params_path')
+    if not analysis_params_path or not os.path.exists(analysis_params_path):
+        raise HTTPException(status_code=500, detail=f"Analysis params_path {analysis_params_path} not found")
+    
+    with open(analysis_params_path,"r") as f:
+        analysis_params = json.load(f)
+        if "sample_list" in analysis_params:
+            sample_list = analysis_params["sample_list"]
+            
+
+
+
     result_dict = {}
     result_list = []
     for item in file_format_list:        
@@ -90,12 +101,13 @@ def execute_parse(analysis,parse,file_format_list):
         args = {
             "dir_path":dir_path,
             # "analysis": dict(result),
-            "file_format":item['fileFormat']
+            "file_format":item['fileFormat'],
+            "sample_list":sample_list
             # "args":moduleArgs,
         
         }
         res = parse(**args)
-        
+       
         for sub_item in  res:
             sub_item.update({
                 "component_id":item['component_id'],
@@ -110,10 +122,20 @@ def execute_parse(analysis,parse,file_format_list):
         result_list = result_list + res
     return result_list,result_dict
 
+def add_run_id(item):
+    item= dict(item)
+    if item['job_status'] == "running":
+        item['run_id'] = f"job-{item['analysis_id']}"
+        item['run_type'] = "job"
+    elif item['server_status'] == "running":
+        item['run_id'] = f"server-{item['analysis_id']}"
+        item['run_type'] = "server"
+    return item
 
 def find_running_analysis(conn):
-    stmt = select(t_analysis).where(t_analysis.c.analysis_status=="running")
+    stmt = select(t_analysis).where(or_(t_analysis.c.job_status == "running",t_analysis.c.server_status == "running"))
     result = conn.execute(stmt).mappings().all()
+    result = [add_run_id(item) for item in result]
     return result
 
 def get_all_files_recursive(directory,dir_name,file_dict):
@@ -136,13 +158,23 @@ def find_analysis_by_id(conn,analysis_id):
     return result
 
 
-async def finished_analysis(analysis_id,status):
+async def finished_analysis(analysis_id,run_type,status):
     with get_engine().begin() as conn:  
-        stmt = (
-            update(t_analysis)
-            .where(t_analysis.c.analysis_id == analysis_id)
-            .values(process_id=None,analysis_status = status)
-        )
+        if run_type == "job":
+            stmt = (
+                update(t_analysis)
+                .where(t_analysis.c.analysis_id == analysis_id)
+                .values(job_status = status)
+            )
+        elif run_type == "server":
+            stmt = (
+                update(t_analysis)
+                .where(t_analysis.c.analysis_id == analysis_id)
+                .values(server_status = status)
+            )
+        else:
+            raise ValueError(f"Invalid run_type: {run_type}")
+        
         conn.execute(stmt)
         conn.commit()
     print(f"Analysis {analysis_id} {status}")
@@ -190,7 +222,7 @@ def list_analysis(conn,query:QueryAnalysis):
         conditions.append(t_analysis.c.component_id.in_(query.component_ids))
     if query.is_report:
         conditions.append(t_analysis.c.is_report)
-    t_sub_container = aliased(t_container)
+    # t_sub_container = aliased(t_container)
 
     stmt = select(
         t_analysis,
@@ -201,15 +233,18 @@ def list_analysis(conn,query:QueryAnalysis):
         t_project.c.project_name.label("project_name"),
         t_container.c.name.label("container_name"),
         t_container.c.image.label("container_image"),
-        t_sub_container.c.name.label("sub_container_name"),
-        t_sub_container.c.image.label("sub_container_image")
+        t_container.c.container_id.label("container_id"),
+        t_container.c.image_status.label("image_status"),
+        t_container.c.image_id.label("image_id")
+        # t_sub_container.c.name.label("sub_container_name"),
+        # t_sub_container.c.image.label("sub_container_image")
     )
 
     stmt = stmt.select_from(
         t_analysis.outerjoin(t_pipeline_components,t_analysis.c.component_id==t_pipeline_components.c.component_id)
         .outerjoin(t_project,t_analysis.c.project==t_project.c.project_id)
         .outerjoin(t_container,t_pipeline_components.c.container_id==t_container.c.container_id)
-        .outerjoin(t_sub_container,t_pipeline_components.c.sub_container_id==t_sub_container.c.container_id)
+        # .outerjoin(t_sub_container,t_pipeline_components.c.sub_container_id==t_sub_container.c.container_id)
         )
     if conditions:
         stmt = stmt.where(and_(*conditions) if len(conditions) > 1 else conditions[0])
