@@ -11,7 +11,7 @@ import shutil
 from fastapi import Depends, HTTPException
 from brave.api.schemas.pipeline import PagePipelineQuery, SavePipeline,Pipeline,QueryPipeline,QueryModule,SaveOrder,SavePipelineComponentsEdges
 from brave.api.config.db import get_engine
-from brave.api.models.core import t_namespace, t_pipeline_components, t_pipeline_components_edges, t_pipeline_components_relation
+from brave.api.models.core import  t_pipeline_components, t_pipeline_components_edges, t_pipeline_components_relation
 import importlib.resources as resources
 from sqlalchemy import delete, select, and_, join, func,insert,update,or_
 from datetime import datetime
@@ -56,13 +56,13 @@ def find_component_module(component,script_name:ScriptName) -> dict:
             raise HTTPException(status_code=500, detail=f"script_type {script_type} not found!")
     else:
         file_type = "py"
-    module_info = find_module(component['namespace'],component['component_id'],script_name,file_type)
+    module_info = find_module(component['component_id'],script_name,file_type)
     if module_info:
         return module_info
     else:
         if script_name == ScriptName.main:
-            create_file(component['namespace'],component['component_id'],component['component_type'],file_type)
-            module_info = find_module(component['namespace'],component['component_id'],script_name,file_type)
+            create_file(component['component_id'],component['component_type'],file_type)
+            module_info = find_module(component['component_id'],script_name,file_type)
             if not module_info:
                 raise HTTPException(status_code=500, detail=f"组件{component.component_id}的{script_name.value}模块没有找到!")
             return module_info
@@ -71,17 +71,12 @@ def find_component_module(component,script_name:ScriptName) -> dict:
             return default_module
         # else:
         #     raise HTTPException(status_code=500, detail=f"{script_name.value}没有找到默认模块!")
-    # try:
-    # except Exception as e:
-    #     print(f"Component with id {component.component_id} not found or missing content.")
-    #     module_path =  create_file(component.namespace,component.component_id,content,component.component_type,file_type)
-
-    # return module_path
 
 
 
 
-def find_module(namespace,module_dir,script_name:ScriptName,file_type):
+
+def find_module(module_dir,script_name:ScriptName,file_type):
     # if script_name == ScriptName.input_parse:
     # if not module_name:
     #     if  module_type == "script":
@@ -92,7 +87,7 @@ def find_module(namespace,module_dir,script_name:ScriptName,file_type):
         # raise HTTPException(status_code=500, detail=f"模块名称不能为空!")
     # if module_name =="default":
        
-    path_dict = get_all_module(namespace,file_type)
+    path_dict = get_all_module(file_type)
     # if module_name is None: 
     #     module_name = module_type
     if module_dir in path_dict:
@@ -125,14 +120,14 @@ def get_default_module(script_name:ScriptName):
             "path":str(py_parse_analysis_result)
         }
     raise HTTPException(status_code=500, detail=f"{script_name.value}没有找到默认模块!")
-def get_all_module(namespace,file_type):
+def get_all_module(file_type):
     suffix = file_type
     # if module_type.startswith("py_"):
     #     suffix = "py"
     # else:
     #     suffix = "nf"
     pipeline_dir =  get_pipeline_dir()
-    nextflow_list = glob.glob(f"{pipeline_dir}/{namespace}/*/*/*.{suffix}")
+    nextflow_list = glob.glob(f"{pipeline_dir}/*/*/*.{suffix}")
     result = {}
     for item in nextflow_list:
         
@@ -173,9 +168,9 @@ def delete_wrap_pipeline_dir(pipeline_key):
     #     if not os.path.exists(item):
     #         os.makedirs(item) 
 
-def create_file(namespace,component_id,component_type,file_type):
+def create_file(component_id,component_type,file_type):
     pipeline_dir = get_pipeline_dir()
-    pipeline_dir = f"{pipeline_dir}/{namespace}"
+    pipeline_dir = f"{pipeline_dir}"
 
     content_text = ""
     if file_type == "py":
@@ -314,8 +309,7 @@ def list_pipeline(conn,queryPipeline:QueryPipeline):
     conditions = []
     if queryPipeline.component_type is not None:
         conditions.append(t_pipeline_components.c.component_type == queryPipeline.component_type)
-    if queryPipeline.namespace is not None:
-        conditions.append(t_pipeline_components.c.namespace == queryPipeline.namespace)
+
     # if analysisResultQuery.ids is not None:
     #     conditions.append(analysis_result.c.id.in_(analysisResultQuery.ids))
     # if analysisResultQuery.analysis_method is not None:
@@ -339,19 +333,14 @@ def format_pipeline_componnet_one(item):
         print("component json error",json.dumps(item,indent=4))
  
         # else:
-        #     item['img'] = f"/brave-api/pipeline-dir/{item['namespace']}/{item['component_type']}/{item['component_id']}/{item['img']}"
     return item
 
 def page_pipeline(conn,query:PagePipelineQuery):
     stmt =select(
         t_pipeline_components,
-        t_namespace.c.name.label("namespace_name")
     ) 
     
-    # Left join with t_namespace to get namespace name
-    stmt = stmt.select_from(
-       t_pipeline_components.outerjoin(t_namespace, t_pipeline_components.c.namespace == t_namespace.c.namespace_id)
-    )
+   
 
     conditions = []
     if query.component_type is not None:
@@ -384,56 +373,13 @@ def page_pipeline(conn,query:PagePipelineQuery):
     }
 
 
-def write_all_component(conn,namespace):
-    pipeline_dir = get_pipeline_dir()
-    pipeline_dir = f"{pipeline_dir}/{namespace}"
-    stmt = t_pipeline_components.select().where(t_pipeline_components.c.namespace == namespace)
-    find_pipeline = conn.execute(stmt).mappings().all()
-    find_pipeline = [ {k:v for k,v in item.items() if k!="id"} for item in find_pipeline]
-    with open(f"{pipeline_dir}/pipeline_component.json","w") as f:
-        json.dump(find_pipeline,f)
-     
 
-def import_component(conn,namespace,force=False):
-    pipeline_dir = get_pipeline_dir()
-    pipeline_dir = f"{pipeline_dir}/{namespace}"
-    with open(f"{pipeline_dir}/pipeline_component.json","r") as f:
-        find_pipeline = json.load(f)
-    for item in find_pipeline:
-        find_pipeline_component = find_pipeline_by_id(conn,item['component_id'])
-        if find_pipeline_component:
-            if force:
-                update_stmt = update(t_pipeline_components).where(t_pipeline_components.c.component_id == item['component_id']).values(item)
-                conn.execute(update_stmt)
-        else:
-            conn.execute(insert(t_pipeline_components).values(item))    
+ 
 def datetime_converter(o):
     if isinstance(o, datetime):
         return o.isoformat()
     raise TypeError(f"Type {type(o)} not serializable")
 
-def write_all_component_relation(conn,namespace):
-    pipeline_dir = get_pipeline_dir()
-    pipeline_dir = f"{pipeline_dir}/{namespace}"
-    stmt = t_pipeline_components_relation.select().where(t_pipeline_components_relation.c.namespace == namespace)
-    find_pipeline = conn.execute(stmt).mappings().all()
-    find_pipeline = [ {k:v for k,v in item.items() if k!="id" and k!="created_at" and k!="updated_at"} for item in find_pipeline]
-    with open(f"{pipeline_dir}/pipeline_component_relation.json","w") as f:
-        json.dump(find_pipeline,f, default=datetime_converter)
-
-def import_component_relation(conn,namespace,force=False):
-    pipeline_dir = get_pipeline_dir()
-    pipeline_dir = f"{pipeline_dir}/{namespace}"
-    with open(f"{pipeline_dir}/pipeline_component_relation.json","r") as f:
-        find_pipeline = json.load(f)
-    for item in find_pipeline:
-        find_pipeline_component_relation = find_by_relation_id(conn,item['relation_id'])
-        if find_pipeline_component_relation:
-            if force:
-                update_stmt = update(t_pipeline_components_relation).where(t_pipeline_components_relation.c.relation_id == item['relation_id']).values(item)
-                conn.execute(update_stmt)
-        else:
-            conn.execute(insert(t_pipeline_components_relation).values(item))   
 
 
 def find_by_relation_id(conn,relation_id:str):
@@ -443,15 +389,11 @@ def find_by_relation_id(conn,relation_id:str):
 
 
 
-def find_component_by_namespace(conn,namespace):
-    stmt = t_pipeline_components.select().where(t_pipeline_components.c.namespace == namespace)
-    return conn.execute(stmt).mappings().all()
-
 def find_component_by_container_id(conn,container_id):
     stmt = t_pipeline_components.select().where(t_pipeline_components.c.container_id == container_id)
     return conn.execute(stmt).mappings().all()
 
-def get_child_depend_component(conn,namespace, component_id):
+def get_child_depend_component(conn, component_id):
     
     stmt = select(
         t_pipeline_components_relation.c.relation_id,
@@ -460,7 +402,6 @@ def get_child_depend_component(conn,namespace, component_id):
         t_pipeline_components.c.component_type,
         t_pipeline_components.c.component_name,
         t_pipeline_components.c.description,
-        t_pipeline_components.c.namespace
         ).select_from(
             t_pipeline_components_relation.outerjoin(
                 t_pipeline_components,
@@ -468,14 +409,13 @@ def get_child_depend_component(conn,namespace, component_id):
             )
         ).where(
             t_pipeline_components_relation.c.parent_component_id == component_id,
-            t_pipeline_components_relation.c.namespace == namespace
         )
     
 
 
     return conn.execute(stmt).mappings().all()
 
-def get_parent_depend_component(conn, namespace, component_id):
+def get_parent_depend_component(conn, component_id):
 
     stmt = select(
         t_pipeline_components_relation.c.relation_id,
@@ -484,7 +424,6 @@ def get_parent_depend_component(conn, namespace, component_id):
         t_pipeline_components.c.component_type,
         t_pipeline_components.c.component_name,
         t_pipeline_components.c.description,
-        t_pipeline_components.c.namespace
     ).select_from(
         t_pipeline_components_relation.outerjoin(
             t_pipeline_components,
@@ -492,18 +431,16 @@ def get_parent_depend_component(conn, namespace, component_id):
         )
     ).where(
         t_pipeline_components_relation.c.component_id == component_id,
-        t_pipeline_components_relation.c.namespace == namespace
     )
     return conn.execute(stmt).mappings().all()
 
 
 
 
-def get_child_component_count(conn,namespace, component_id,relation_type):
+def get_child_component_count(conn, component_id,relation_type):
     stmt = select(func.count()).select_from(t_pipeline_components_relation).where(
         t_pipeline_components_relation.c.parent_component_id == component_id,
         t_pipeline_components_relation.c.relation_type == relation_type,
-        t_pipeline_components_relation.c.namespace == namespace
     )
     return conn.execute(stmt).scalar()
 
@@ -544,19 +481,15 @@ def get_pipeline_v2(conn,name,component_type="pipeline"):
         t_pipeline_components.c.component_type,
         t_pipeline_components.c.install_key,
         t_pipeline_components.c.content,
-        t_pipeline_components.c.namespace,
         t_pipeline_components.c.component_name,
         t_pipeline_components.c.position,
         t_pipeline_components.c.edges,
         t_pipeline_components.c.tags,
         t_pipeline_components.c.description,
-        t_namespace.c.name.label("namespace_name"),
         cast(null(), String(255)).label("relation_type"),
         cast(null(), String(255)).label("parent_component_id"),
         cast(null(), String(255)).label("order_index"),
         cast(null(), String(255)).label("relation_id"),
-    ).select_from(
-        t_pipeline_components.outerjoin(t_namespace, t_pipeline_components.c.namespace == t_namespace.c.namespace_id)
     ).where(
         t_pipeline_components.c.component_id == name,
         t_pipeline_components.c.component_type == component_type,
@@ -567,7 +500,6 @@ def get_pipeline_v2(conn,name,component_type="pipeline"):
     # cte = base.cte(name="full_pipeline", recursive=True)
 
     tp1 = aliased(t_pipeline_components)
-    tn1 = aliased(t_namespace)
     rel = t_pipeline_components_relation
     # fp = aliased(cte)  # 引用递归CTE自身
     base_alias = base.alias()
@@ -577,20 +509,17 @@ def get_pipeline_v2(conn,name,component_type="pipeline"):
         tp1.c.component_type,
         tp1.c.install_key,
         tp1.c.content,
-        tp1.c.namespace,
         tp1.c.component_name,
         tp1.c.position,
         tp1.c.tags,
         tp1.c.edges,
         tp1.c.description,
-        tn1.c.name.label("namespace_name"),
         rel.c.relation_type,
         rel.c.parent_component_id,
         rel.c.order_index,
         rel.c.relation_id,
     ).select_from(
-        tp1.outerjoin(tn1, tp1.c.namespace == tn1.c.namespace_id)
-        .join(rel, tp1.c.component_id == rel.c.component_id)
+        tp1.join(rel, tp1.c.component_id == rel.c.component_id)
         .join(base_alias, rel.c.parent_component_id == base_alias.c.component_id)
     )
 
@@ -722,4 +651,141 @@ def build_pipeline_structure(id_to_node,children_map,root_item):
 def update_component_description(conn, component_id,description):
     stmt = t_pipeline_components.update().where(t_pipeline_components.c.component_id ==component_id).values(description=description)
     conn.execute(stmt)
-    # pass
\ No newline at end of file
+    # pass
+
+
+
+
+
+
+
+def get_components(conn, component_id):
+    base = (
+        select(t_pipeline_components)
+        .where(t_pipeline_components.c.component_id == component_id)
+        .cte(name="base", recursive=True)
+    )
+    tp1 = aliased(t_pipeline_components)
+    rel = t_pipeline_components_relation
+    base_alias = base.alias()
+
+    # Use INNER JOINs for the recursive part to comply with MySQL's CTE restrictions
+    recursive = (
+        select(tp1)
+        .select_from(
+            tp1.join(rel, tp1.c.component_id == rel.c.component_id)
+               .join(base_alias, rel.c.parent_component_id == base_alias.c.component_id)
+        )
+    )
+
+    cte = base.union_all(recursive)
+    final_query = select(cte)
+    data = conn.execute(final_query).mappings().all()
+    return data
+
+def get_component_relation(conn,component_id):
+    base = (select(
+        t_pipeline_components_relation
+    ).where(
+        t_pipeline_components_relation.c.parent_component_id == component_id,
+    ).cte(name="base", recursive=True))
+    tr1 = aliased(t_pipeline_components_relation)
+
+    base_alias = base.alias()
+
+    recursive = select(tr1).select_from(
+        tr1.join(base_alias, tr1.c.parent_component_id == base_alias.c.component_id)
+    )
+
+    cte = base.union_all(recursive) 
+    final_query = select(cte)
+    data = conn.execute(final_query).mappings().all()
+    return data
+
+def delete_component_file(component):
+    component_type = component["component_type"]
+    component_id = component["component_id"]
+    pipeline_dir = get_pipeline_dir()
+    pipeline_dir = f"{pipeline_dir}/{component_type}/{component_id}"
+    if os.path.exists(pipeline_dir):
+        shutil.rmtree(pipeline_dir)
+
+def write_component_json(component_id):
+    with get_engine().begin() as conn:
+        component_list = get_components(conn,component_id)
+        component_relation_list =  get_component_relation(conn,component_id)
+        container_id_list = [ item['container_id'] for item in component_list if item['container_id'] is not None ]
+        container_list = container_service.find_by_container_ids(conn,container_id_list)
+    
+    current_component = [item for item in component_list if item.component_id == component_id]
+    if not current_component:
+        raise HTTPException(status_code=500, detail=f"组件{component_id}没有找到!")
+    current_component = current_component[0]
+    component_type = current_component["component_type"]
+    pipeline_dir = get_pipeline_dir()
+    pipeline_dir = f"{pipeline_dir}/{component_type}/{component_id}"
+    if not os.path.exists(pipeline_dir):
+        os.makedirs(pipeline_dir)
+    
+    pipeline_component_file = f"{pipeline_dir}/pipeline_component.json"
+    pipeline_component_relation_file = f"{pipeline_dir}/pipeline_component_relation.json"
+    with open(pipeline_component_file,"w") as f:
+        json.dump([ {k:v for k,v in item.items() if k!="id"} for item in component_list],f, default=datetime_converter)
+    with open(pipeline_component_relation_file,"w") as f:
+        json.dump([ {k:v for k,v in item.items() if k!="id" and k!="created_at" and k!="updated_at"} for item in component_relation_list],f, default=datetime_converter)    
+
+    container_file = f"{pipeline_dir}/container.json"
+    container_list = [ {k:v for k,v in item.items() if k!="id" and k!="created_at" and k!="updated_at"} for item in container_list]
+    with open(container_file,"w") as f:
+        json.dump(container_list,f)
+    
+    install_file = f"{pipeline_dir}/install.json"
+    with open(install_file,"w") as f:
+        json.dump({
+            "component_type":component_type,
+            "component_id":component_id,
+            "component_name":current_component["component_name"],
+            "img":os.path.basename(current_component["img"]) if current_component["img"] else "",
+        },f)
+    
+
+        # component = t_pipeline_components.select().where(t_pipeline_components.c.component_id ==component_id)
+    print(f"export pipeline_component_file: {pipeline_component_file}!")
+    print(f"export pipeline_component_relation_file: {pipeline_component_relation_file}!")
+    print(f"export container_file: {container_file}!")
+
+    pass
+
+
+
+def import_component_relation(conn,path,force=False):
+    # pipeline_dir = get_pipeline_dir()
+    with open(f"{path}/pipeline_component_relation.json","r") as f:
+        find_pipeline = json.load(f)
+    for item in find_pipeline:
+        find_pipeline_component_relation = find_by_relation_id(conn,item['relation_id'])
+        if find_pipeline_component_relation:
+            if force:
+                update_stmt = update(t_pipeline_components_relation).where(t_pipeline_components_relation.c.relation_id == item['relation_id']).values(item)
+                conn.execute(update_stmt)
+        else:
+            conn.execute(insert(t_pipeline_components_relation).values(item))   
+def import_component(conn,path,force=False):
+
+    with open(f"{path}/pipeline_component.json","r") as f:
+        find_pipeline = json.load(f)
+    for item in find_pipeline:
+        find_pipeline_component = find_pipeline_by_id(conn,item['component_id'])
+        if find_pipeline_component:
+            if force:
+                update_stmt = update(t_pipeline_components).where(t_pipeline_components.c.component_id == item['component_id']).values(item)
+                conn.execute(update_stmt)
+        else:
+            conn.execute(insert(t_pipeline_components).values(item))   
+
+
+# Find components by a list of component IDs
+def find_by_component_ids(conn,component_ids):
+    stmt = t_pipeline_components.select().where(t_pipeline_components.c.component_id.in_(component_ids))
+    find_pipeline = conn.execute(stmt).mappings().all()
+    return find_pipeline
