@@ -29,16 +29,21 @@ class NextflowAnalysis(BaseAnalysis):
                 {component_script} \\
                 -params-file {params_path} \\
                 -w {work_dir} \\
-                -plugins nf-hello@0.7.0 \\
                 -c {nextflow_config} \\
                 -with-trace {trace_file} | tee {workflow_log_file} ; exit ${{PIPESTATUS[0]}}
             """)
+        # -plugins nf-hello@0.7.0 \\
+
         return command
         
     def write_config(self,output_dir,component_script):
         script_config_file = f"{output_dir}/nextflow.config"
         script_config =  textwrap.dedent(f"""
         trace.overwrite = true
+        docker{{
+            enabled = true
+            runOptions = '--user $(id -u):$(id -g)'
+        }}
         """)
         with open(script_config_file, "w") as f:
             f.write(script_config)
