@@ -10,6 +10,8 @@ from brave.api.handlers import analysis_executer
 from brave.api.service.listener_files_service import get_listener_files_service
 from brave.api.service.process_monitor_service import ProcessMonitor
 from brave.api.service.sse_service import SSESessionService
+from brave.api.config.db import get_engine
+from brave.api.service import namespace_service, project_service
 from brave.api.ingress.manager import IngressManager
 from brave.api.handlers import workflow_events,analysis_result   
 from brave.api.core.workflow_queue import WorkflowQueueManager
@@ -76,7 +78,7 @@ class AppManager:
         #     auth=(self.settings.user, self.settings.password)
         # )
 
-        self.graph  = Graph("bolt://localhost:7687", auth=("neo4j", "password"))
+        # self.graph  = Graph("bolt://localhost:7687", auth=("neo4j", "password"))
 
         self.file_watcher_service = FileWatcherService(
             watch_path=watch_path,
@@ -131,11 +133,7 @@ class AppManager:
         # self.workflow_event_router.register_handler(WorkflowEvent.ON_FLOW_COMPLETE,  push_default_message)
         # self.workflow_event_router.register_handler(WorkflowEvent.ON_JOB_SUBMITTED,  push_default_message)
 
-        # def finished_analysis_handler(analysis_id:str,msg:dict  ):
-        #     # analysis_id = msg.get("analysis_id")
-        #     if analysis_id:
-        #         asyncio.create_task(analysis_service.finished_analysis(analysis_id))
-
+     
         # self.workflow_event_router.register_handler(WorkflowEvent.ON_FLOW_COMPLETE, finished_analysis_handler)
 
         # self.workflow_queue_manager.register_subscriber("", subscriber)
@@ -160,6 +158,13 @@ class AppManager:
         # 挂载到 app.state，方便别处访问
         # self.app.state.manager = self
 
+        # init db
+        with get_engine().begin() as conn: 
+            await namespace_service.init_db(conn)
+            await project_service.init_db(conn)
+
+        
+
     async def stop(self):
         for task in self.tasks:
             task.cancel()
